<?php
/**
* Get related posts
*
* @since Reef 0.1
* @param array $taxonomy
* @param int $per_page Default 3
* @return bool | object
* 
*/
if( ! function_exists( 'reef_get_related_posts' ) ):

function reef_get_related_posts( $taxonomy = array(), $per_page = 3, $get_params = false ){
   
    # Show related posts only in single page.
    if ( !is_single() )
        return false;

    # Get the current post object to start of
    $current_post = get_queried_object();

    # Get the post terms, just the ids
    $terms = wp_get_post_terms( $current_post->ID, $taxonomy, array( 'fields' => 'ids' ) );

    # Lets only continue if we actually have post terms and if we don't have an WP_Error object. If not, return false
    if ( !$terms || is_wp_error( $terms ) )
        return false;
    
    # Check if the users argument is valid
    if( is_array( $taxonomy ) && count( $taxonomy ) > 0 ){

    	$tax_query_arg = array();

    	foreach( $taxonomy as $tax ){

    		$tax = filter_var( $tax, FILTER_SANITIZE_STRING );

		    if ( taxonomy_exists( $tax ) ){

		    	array_push( $tax_query_arg, array(
		    		'taxonomy'         => $tax,
		    		'terms'            => $terms,
		    		'include_children' => false
		    	) );
	        	
		    }
    	}

    	if( count( $tax_query_arg ) == 0 ){
    		return false;
    	}

    	if( count( $tax_query_arg ) > 1 ){
    		$tax_query_arg[ 'relation' ] = 'OR';
    	}
    	
    }else
        return false;
    
    # Set the default query arguments
    $args = array(
        'post_type'      => $current_post->post_type,
        'post__not_in'   => array( $current_post->ID ),
        'posts_per_page' => $per_page,
        'tax_query'      => $tax_query_arg,
    );

    if( $get_params ){
        return $args;
    }
    
    # Now we can query our related posts and return them
    $q = get_posts( $args );

    return $q;
}
endif;

/**
* Adds a class 'clearfix' on post navigation markup 	
*	
* @since Reef 0.1	
* @param string $template	
* @param string $class	
* @return string	
*/	
function reef_modify_post_navigation_markup( $template, $class ){

	$pos = strpos( $template,'%1$s' );
	$template = substr_replace( $template, 'clearfix ', $pos, 0 );
	
	return $template;

}
add_filter( 'navigation_markup_template', 'reef_modify_post_navigation_markup', 10, 2 );

/**
 * Fallback for primary menu.
 *
 * @since Reef 0.1
 * @return void
 */
if( ! function_exists( 'reef_primary_menu_fb' ) ) :

function reef_primary_menu_fb( $arg ) {
    if( !$arg[ 'echo' ] ){
        ob_start();
    }
    ?>
    <ul>
        <li>
            <a href="<?php echo esc_url( home_url( '/' ) ) ?>"><?php esc_html_e( 'Home', 'reef' ) ?></a>
        </li>
    </ul>
    <?php
    if( !$arg[ 'echo' ] ){
        $data = ob_get_contents();
        ob_end_clean();
        return $data;
    }
}
endif;

/**
 * Returns youtubes video id from the url.
 *
 * @since Reef 0.1
 * @param string $url
 * @return string | bool
 */
if( !function_exists( 'reef_get_youtube_id' ) ):
function reef_get_youtube_id( $url ) {

    $parts = parse_url( $url );

    if( isset( $parts[ 'query' ] ) ){

        parse_str( $parts[ 'query' ], $qs );

        if( isset( $qs[ 'v' ] ) ){
            return $qs[ 'v' ];
        }else if( isset( $qs[ 'vi' ] ) ){
            return $qs[ 'vi' ];
        }
    }

    if( isset( $parts[ 'path' ] ) ){
        $path = explode( '/', trim( $parts[ 'path' ], '/' ) );
        return $path[ count( $path )-1 ];
    }
    return false;
}
endif;

/**
* Generates placeholder image url
*
* @since  Reef 0.1
* @param  string $size The image size for which to retrieve data.
* @return string Url of the dummy image. 
*/
if ( ! function_exists( 'reef_get_dummy_image' ) ) :

function reef_get_dummy_image( $args ) {
    
    $defaults = array(
        'size'       => 'thumbnail',
    );

    $args = wp_parse_args( $args, $defaults );

    if( 'medium_large' == $args[ 'size' ] || 'full' == $args[ 'size' ] ){
        $args[ 'size' ] = 'large';
    }

    $url = get_theme_file_uri( 'assets/images/placeholder/' . $args[ 'size' ] . '-placeholder.png' );

    return esc_url( apply_filters( 'reef_dummy_image', $url, $args ) );
}
endif;

/**
* Returns categories after sorting by term id descending
* 
* @since Reef 1.2
* @uses reef_sort_category()
* @return array
*/
if( ! function_exists( 'reef_get_the_category' ) ):


function reef_get_the_category( $id = false ){

    $failed = true;

    # Check if Yoast Plugin is installed 
    # If yes then, get Primary category, set by Plugin

    if ( class_exists('WPSEO_Primary_Term') ){

        # Show the post's 'Primary' category, if this Yoast feature is available, & one is set
        $wpseo_primary_term = new WPSEO_Primary_Term( 'category', get_the_id() );
        $wpseo_primary_term = $wpseo_primary_term->get_primary_term();

        $cat[0] = get_term( $wpseo_primary_term );

        if ( !is_wp_error($cat[0])) { 
           $failed = false;
        }
    }

    if( $failed ){

      $cat = get_the_category( $id );
      usort( $cat, 'reef_sort_category' );  
    }
    
    return $cat;
}

endif;

/**
* Helper function for reef_get_the_category()
*
* @since Reef 1.3
*/
if( ! function_exists( 'reef_sort_category' ) ):
    function reef_sort_category( $a, $b ){
        return $a->term_id < $b->term_id;
    }
endif;

/**
* Determines weather the site is in root position or frontpage
*
* @since Reef 1.3
* @return Bool
*/
if( !function_exists( 'reef_is_root' ) ):
    function reef_is_root(){

        $home_url = get_home_url() . '/';
        $current_url = 'http://'.filter_input( INPUT_SERVER, 'HTTP_HOST' ).filter_input( INPUT_SERVER, 'REQUEST_URI' );

        if( $home_url == $current_url )
            return true;
        
        return false;
    }
endif;